@@ -1,6 +1,12 @@
 #' List aloft urls for time series of vertical profiles (`vpts`) of radar
 #' stations
 #'
+#' @description
+#' `r lifecycle::badge("superseded")`
+#'
+#' This function has been superseded by `getRad::get_vpts()` and
+#' `getRad::aloft_data_coverage()`.
+#'
 #' @param date_min Character, the first date to return urls for. In the shape of
 #'   YYYY-MM-DD.
 #' @param date_max Character, the last date to return urls for. In the shape of
@@ -26,6 +32,8 @@ list_vpts_aloft <- function(date_min = NULL,
                             format = "csv", # also hdf5
                             source = "baltrad", # also ecog-04003
                             show_warnings = TRUE) {
+  lifecycle::deprecate_warn("2025", "list_vpts_aloft()", "getRad::get_vpts()")
+
   # Check if aws.s3 is installed
   # NOTE added because aws.s3 is schedueled to be moved to Suggests
 
